<?xml version="1.0" ?><!DOCTYPE TS><TS language="ms" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Ralat Ungkapan</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark Theme</source>
        <translation>Tema Gelap</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Mod ringkas</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Mod saintifik</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Kalkulator Deepin</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Kalkulator Deepin merupakan kalkulator desktop yang ringkas dan mudah digunakan. Ia menyokong fungsi tambah, tolak, darab dan bahagi.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Ralat Ungkapan</translation>
    </message>
</context>
</TS>